import {Schema} from 'prosemirror-model'

export function loadSchema (components) {
  const schemaSpec = {nodes: {}, marks: {}}
  for (const component of components) {
    Object.assign(schemaSpec.nodes, component.nodes || {})
    Object.assign(schemaSpec.marks, component.marks || {})
  }

  for (const component of components) {
    if (component.patchSchema) {
      component.patchSchema(schemaSpec)
    }
  }

  return new Schema(schemaSpec)
}

export function isMac () {
  return typeof navigator !== 'undefined' ? /Mac/.test(navigator.platform) : false
}

export function buildKeymap (components, schema) {
  let keys = {}

  for (const component of components) {
    if (component.keymap) {
      Object.assign(keys, component.keymap(schema))
    }
  }

  return keys
}
